#!/bin/bash

function config_cpe {
    SERIAL=$1
    KEY=$2
    ADDRESS=$3
    PREFIX=32
    OUTPUT_FILE="$4"

    [[ "${ADDRESS}" =~ ^([0-9|\.]*)/([0-9]*)$ ]] && { ADDRESS=${BASH_REMATCH[1]}; PREFIX=${BASH_REMATCH[2]}; }

    ITEM="item={\"id\":1,\"strs\":{\"event\":\"cpe_conf\", \"serial\":\"${SERIAL}\""

    [ -n "${ADDRESS}" ] && ITEM="$ITEM, \"address\": \"${ADDRESS}\", \"prefix-length\": \"${PREFIX}\""
    [ -n "${KEY}" ] && ITEM="$ITEM, \"private-key\": \"${KEY}\""
    [ -n "${OUTPUT_FILE}" ] && ITEM="$ITEM, \"output-file\": \"${OUTPUT_FILE}\""
    ITEM="$ITEM""},\"strstrs\":{},\"bools\":{},\"u64s\":{},\"ids\":{}}"

    RESPONSE=`curl -X POST -F "${ITEM}" "http://${MGR_HOST}:${MGR_PORT}/cpe_event" 2>&1` || \
        { echo execution failed for CPE $1: $RESPONSE; exit; }
}

function help {
    printf "Usage: %s -f FILENAME\n" $(basename $0)
    printf "       %s \[-o OUTPUT_FILE\] SERIAL \[KEY ADDRESS\]\n" $(basename $0)
    printf "\n"
    printf "       The file FILENAME should have a number of lines SERIAL KEY ADDRESS\n"
    exit
}

if [ "$1" == "--help" -o "$1" == "-h" ]
then
    help
fi

MGR_HOST=localhost
MGR_PORT=8090

if [ "$1" == "-f" ]
then
    if [ ! -f "$2" ]
    then
        echo The file \"$2\" is not available
        exit
    fi

    cat "$2" | \
    while read LN
    do
        LINE=( $LN )
        if [ ${#LINE[@]} -ne 3 ]
        then
            echo wrong line $LN
            exit
        fi
        config_cpe "${LINE[0]}" "${LINE[1]}" "${LINE[2]}"
    done
else
    if [ "$1" == "-o" -a ${#@} -ge 3 ]
    then
        config_cpe "$3" "$4" "$5" "$2"
    elif [ ${#@} -eq 3 ]
    then
        config_cpe "$1" "$2" "$3"
    else
        echo Error in parameters
        help
    fi
fi
